@@ -638,8 +638,10 @@ class GraspManager(ActivityBase):
                         self.post_release_pose = post_release_pose
                         self.obj_release_pose = result_obj_pose
                         self.obj_post_release_pose = result_obj_pose
-                        is_success_filtered = True
-                        break
+                        
+                        if self._check_between_object_distances():
+                            is_success_filtered = True
+                            break
 
         if not is_success_filtered:
             logger.error(f"Failed to filter Release poses")
@@ -655,7 +657,8 @@ class GraspManager(ActivityBase):
         self,
         obj_mesh,
         obj_pose,
-        n_samples
+        n_samples,
+        alpha=0.6
     ):
         """
         Generate support points
@@ -664,7 +667,8 @@ class GraspManager(ActivityBase):
             obj_mesh (trimesh.base.Trimesh): mesh of support object
             obj_pose (np.array): pose of support object
             n_samples (int): number of sampling points on support object
-           
+            alpha (float): 
+
         Returns:
             point, normal_vector (tuple)
         """
@@ -674,12 +678,16 @@ class GraspManager(ActivityBase):
         weights = np.zeros(len(copied_mesh.faces))
         for idx, vertex in enumerate(copied_mesh.vertices[copied_mesh.faces]):
             weights[idx]=0.0
-            if np.all(vertex[:,2] >= copied_mesh.bounds[1][2] * 0.98):                
+            if np.all(vertex[:,2] >= copied_mesh.bounds[1][2] * 0.98):
                 weights[idx] = 1.0
 
         support_points, _, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
         for point, normal_vector in zip(support_points, normal_vectors):
-            yield point, normal_vector
+            len_x = abs(copied_mesh.bounds[0][0] - copied_mesh.bounds[1][0])/2
+            len_y = abs(copied_mesh.bounds[0][1] - copied_mesh.bounds[1][1])/2
+            if copied_mesh.bounds[0][0] + len_x * alpha <= point[0] <= copied_mesh.bounds[1][0] - len_x * alpha:
+                if copied_mesh.bounds[0][1] + len_y * alpha <= point[1] <= copied_mesh.bounds[1][1] - len_y * alpha:
+                    yield point, normal_vector
 
     def generate_points_for_support(
         self,
@@ -763,4 +771,12 @@ class GraspManager(ActivityBase):
             self.obj_support_point = locations[support_index[0]]
             return True
         logger.warning("Not found support point")
-        return False
\ No newline at end of file
+        return False
+
+    def _check_between_object_distances(self):
+        distance_info = self.object_c_manager.get_distances_internal()
+        distances = []
+        for (o1, o2), distance in distance_info.items():
+            if o1 == self.obj_info["name"] and o2 in list(self.object_c_manager.objects.grasp_objects.keys()):
+                distances.append(distance)
+        return np.all(self.release_distance <= np.array(distances))
\ No newline at end of file
